spannertools.get_spanners_that_dominate_component_pair
======================================================

.. autofunction:: abjad.tools.spannertools.get_spanners_that_dominate_component_pair.get_spanners_that_dominate_component_pair
